API Reference
=============

.. automodule:: referencing
   :members:
   :undoc-members:
   :imported-members:
   :special-members: __iter__, __getitem__, __len__


.. autoclass:: referencing._core.Resolved
   :members:
   :undoc-members:


.. autoclass:: referencing._core.Resolver
   :members:
   :undoc-members:


Submodules
----------

referencing.jsonschema
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: referencing.jsonschema
   :members:
   :undoc-members:


referencing.exceptions
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: referencing.exceptions
   :members:
   :show-inheritance:
   :undoc-members:


referencing.typing
^^^^^^^^^^^^^^^^^^

.. automodule:: referencing.typing
   :members:
   :undoc-members:
